@@ -3,14 +3,12 @@ from __future__ import annotations
 import decimal
 import functools
 import hashlib
-import json
 import re
 import struct
 from decimal import Decimal
 from typing import Callable, List, Optional, Union, Dict
 
 import dezimal
-import yaml
 from dezimal import Dezimal
 
 from jinsi.exceptions import NoMergePossible
@@ -179,14 +177,14 @@ def substitute(thing, callback: Callable[[str], str]):
     if isinstance(thing, (type(None), bool, int, float)):
         return thing
     if isinstance(thing, str):
-        fs = re.split(r"<<(\$?[a-zA-Z0-9-_]+)>>", thing)
+        fs = re.split(r"<<(\$?[a-zA-Z0-9-_]+(\.[a-zA-Z0-9-_]+)*)>>", thing)
         result = []
-        is_even = True
+        ix = 0
         for f in fs:
-            is_even = not is_even
-            if is_even:
+            ix = (ix + 1) % 3
+            if ix == 2:
                 result.append(callback(f))
-            else:
+            elif ix == 1:
                 result.append(f)
         return "".join(result)
     elif isinstance(thing, list):
@@ -332,20 +330,3 @@ def treat(value, *, numtype):
 
 
 JsonValue = Union[type(None), bool, int, float, str, List['JsonValue'], Dict[str, 'JsonValue']]
-
-
-def load_all(data: str) -> List[JsonValue]:
-    dec = json.JSONDecoder()
-    data = data.strip()
-    if not data:
-        return
-    while data:
-        try:
-            obj, ix = dec.raw_decode(data)
-        except json.JSONDecodeError as err:
-            break
-        yield obj
-        data = data[ix:].lstrip()
-    if not data:
-        return
-    yield from yaml.load_all(data, Loader=yaml.SafeLoader)
