@@ -120,10 +120,9 @@ for func in aws_cloudformation_intrinsic_functions:
 
 class Dumper(yaml.Dumper):
 
-    def __init__(self, **kwargs):
-        if 'sort_keys' not in kwargs:
-            kwargs['sort_keys'] = False
-        super().__init__(**kwargs)
+    def __init__(self, *args, **kwargs):
+        kwargs['sort_keys'] = False
+        super(Dumper, self).__init__(*args, **kwargs)
 
     def represent_str(self, data):
         if '\n' in data:
@@ -153,3 +152,11 @@ def dumpyaml(data) -> str:
         Dumper=Dumper,
         default_flow_style=False,
     )
+
+
+def loadyaml(stream):
+    return yaml.load(stream, Loader=Loader)
+
+
+def loadyaml_all(stream):
+    return yaml.load_all(stream, Loader=Loader)
